-------------------------------------------------------------------------------
-- Localized Lua globals.
-------------------------------------------------------------------------------
local _G = getfenv(0)

-- Functions

-- Libraries
local string = _G.string
local table = _G.table

-------------------------------------------------------------------------------
-- AddOn namespace.
-------------------------------------------------------------------------------
local FOLDER_NAME, private = ...

local LibStub = _G.LibStub
local addon = LibStub("AceAddon-3.0"):GetAddon(FOLDER_NAME)


-------------------------------------------------------------------------------
-- Hooks.
-------------------------------------------------------------------------------
-- Unfortunately, we have to duplicate the entire Blizzard function just to edit a couple of key entries.
local COMPANION_BUTTON_HEIGHT = 46

function private.PetJournal_FindPetCardIndex()
		local PetJournal = _G.PetJournal
		local C_PetJournal = _G.C_PetJournal
		local PetJournalPetCard = _G.PetJournalPetCard

		PetJournalPetCard.petIndex = nil;
		local numPets = C_PetJournal.GetNumPets(PetJournal.isWild);
		for i = 1, numPets do
			local petID, speciesID, owned = C_PetJournal.GetPetInfoByIndex(i, isWild);
			if (owned and petID == PetJournalPetCard.petID) or
				(not owned and speciesID == PetJournalPetCard.speciesID) then
				PetJournalPetCard.petIndex = i;
				break;
			end
		end
	end

	function private.PetJournal_UpdatePetList()
		local PetJournal = _G.PetJournal
		local C_PetJournal = _G.C_PetJournal
		local HybridScrollFrame_GetOffset = _G.HybridScrollFrame_GetOffset

		local scrollFrame = PetJournal.listScroll;
		local offset = HybridScrollFrame_GetOffset(scrollFrame);
		local petButtons = scrollFrame.buttons;
		local pet, index;

		local isWild = PetJournal.isWild;

		local numPets, numOwned = C_PetJournal.GetNumPets(isWild);
		PetJournal.PetCount.Count:SetText(numOwned);

		local summonedPetID = C_PetJournal.GetSummonedPetID();

		for i = 1, #petButtons do
			pet = petButtons[i];
			index = offset + i;
			if index <= numPets then
				local petID, speciesID, isOwned, customName, level, favorite, isRevoked, name, icon, petType, creatureID, sourceText, description, isWildPet, canBattle = C_PetJournal.GetPetInfoByIndex(private.pet_list[index].journal_index, isWild);

				if customName then
					pet.name:SetText(customName);
					pet.name:SetHeight(12);
					pet.subName:Show();
					pet.subName:SetText(name .. "Mufasa");
				else
					pet.name:SetText(name);
					pet.name:SetHeight(30);
					pet.subName:Hide();
				end
				pet.icon:SetTexture(icon);
				pet.petTypeIcon:SetTexture(GetPetTypeTexture(petType));

				if (favorite) then
					pet.dragButton.favorite:Show();
				else
					pet.dragButton.favorite:Hide();
				end

				if isOwned then
					local health, maxHealth, attack, speed, rarity = C_PetJournal.GetPetStats(petID);

					pet.dragButton.levelBG:SetShown(canBattle);
					pet.dragButton.level:SetShown(canBattle);
					pet.dragButton.level:SetText(level);

					pet.icon:SetDesaturated(0);
					pet.name:SetFontObject("GameFontNormal");
					pet.petTypeIcon:SetShown(canBattle);
					pet.petTypeIcon:SetDesaturated(0);
					pet.dragButton:Enable();
					if (isWildPet) then
						pet.iconBorder:Show();
						pet.iconBorder:SetVertexColor(ITEM_QUALITY_COLORS[rarity - 1].r, ITEM_QUALITY_COLORS[rarity - 1].g, ITEM_QUALITY_COLORS[rarity - 1].b);
					else
						pet.iconBorder:Hide();
					end
					if (health and health <= 0) then
						pet.isDead:Show();
					else
						pet.isDead:Hide();
					end
					if (isRevoked == true) then
						pet.dragButton.levelBG:Hide();
						pet.dragButton.level:Hide();
						pet.iconBorder:Hide();
						pet.icon:SetDesaturated(1);
						pet.petTypeIcon:SetDesaturated(1);
						pet.dragButton:Disable();
					end
				else
					pet.dragButton.levelBG:Hide();
					pet.dragButton.level:Hide();
					pet.icon:SetDesaturated(1);
					pet.iconBorder:Hide();
					pet.name:SetFontObject("GameFontDisable");
					pet.petTypeIcon:SetShown(canBattle);
					pet.petTypeIcon:SetDesaturated(1);
					pet.dragButton:Disable();
					pet.isDead:Hide();
				end

				if (petID and petID == summonedPetID) then
					pet.dragButton.ActiveTexture:Show();
				else
					pet.dragButton.ActiveTexture:Hide();
				end

				pet.petID = petID;
				pet.speciesID = speciesID;
				pet.index = index;
				pet.owned = isOwned;
				pet:Show();

				--Update Petcard Button
				if PetJournalPetCard.petIndex == index then
					pet.selected = true;
					pet.selectedTexture:Show();
				else
					pet.selected = false;
					pet.selectedTexture:Hide()
				end
			else
				pet:Hide();
			end
		end

		local totalHeight = numPets * COMPANION_BUTTON_HEIGHT;
		HybridScrollFrame_Update(scrollFrame, totalHeight, scrollFrame:GetHeight());
	end
